<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ady">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>System Monitor</source>
        <translation>مراقب النظام</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>مراقب النظام هو أداة لرصد تحميل النظام في الوقت الحقيقي، وعرض وتحكم العمليات والخدمات التي تعمل على نظامك.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="28"/>
        <source>Hide details</source>
        <translation>إخفاء التفاصيل</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="39"/>
        <source>Overall utilization</source>
        <translation>الاستخدام الإجمالي</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="42"/>
        <source>Individual utilization</source>
        <translation>الاستخدام الفردي</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="138"/>
        <source>Read</source>
        <translation>القراءة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="142"/>
        <source>Write</source>
        <translation>الكتابة</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="154"/>
        <source>60 seconds</source>
        <translation>60 ثانية</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="43"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 أيام %2 ساعات %3 دقائق</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>الاستخدام</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation>التردد</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>التردد الأقصى</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation>التردد المتوسط</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>وقت التشغيل</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>الsockets</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>المعالجات المنطقية</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>الترميز الافتراضي</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>الذاكرة العشوائية L1i</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>الذاكرة العشوائية L1d</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>الذاكرة العشوائية L2</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>الذاكرة العشوائية L3</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>معدل الأحمال</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>الوصف الملفي</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation type="unfinished">Processes</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>الخيوط</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>اسم المضيف</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>نوع نظام التشغيل</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>النسخة</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="298"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="293"/>
        <source>60 seconds</source>
        <translation>60 ثانية</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="477"/>
        <source>No search results</source>
        <translation>لا توجد نتائج للبحث</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="87"/>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="70"/>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>active</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>reloading</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>inactive</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>failed</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>activating</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>deactivating</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>not-found</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>bad-setting</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>merged</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>masked</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>loaded</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>enabled</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>disabled</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>static</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>transient</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>indirect</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>enabled-runtime</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>masked</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>generated</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>running</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>exited</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>تәкъдім</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>тәкъдім</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>тәкъдім (watchdog)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>тәкъдім (sigterm)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>тәкъдім (sigkill)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>тәкъдім (post)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>final (sigterm)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>final (sigkill)</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>әләй</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>авто-тәкъдім</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <source>Warning</source>
        <translation>Хәбәр</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Сіздің CPU ҡулланылыуыңыз %1%тан ҙурыраҡ!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Сіздің яҙмалыҡ ҡулланылыуыңыз %1%тан ҙурыраҡ!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation type="unfinished">View</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="62"/>
        <source>Used</source>
        <translation>Ишләнгән</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="64"/>
        <source>Available</source>
        <translation>Иҫтәлә булырға</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="68"/>
        <source>Shared</source>
        <translation>Бөтен</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="70"/>
        <source>Cached</source>
        <translation>Бурылған</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="74"/>
        <source>Buffers</source>
        <translation>Буферҙар</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="76"/>
        <source>Cached swap</source>
        <translation>Бурылған swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="80"/>
        <source>Active</source>
        <translation type="unfinished">Active</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="82"/>
        <source>Inactive</source>
        <translation>Актив булмай</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="86"/>
        <source>Dirty</source>
        <translation>Темен</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="88"/>
        <source>Mapped</source>
        <translation>Мапланған</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="92"/>
        <source>Total swap</source>
        <translation>Барлыҡ swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="94"/>
        <source>Free swap</source>
        <translation>Свобод swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="98"/>
        <source>Slab</source>
        <translation>Слаб</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="64"/>
        <source>Model</source>
        <translation>Модель</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="66"/>
        <source>Read speed</source>
        <translation>Ҡына ынаныуы</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Write speed</source>
        <translation>Яҙыу ынаныуы</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Capacity</source>
        <translation>Ҡабатлау</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Sectors read</source>
        <translation>Ҡына ынаныуы</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Reads/s</source>
        <translation>خәтә/с</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read/s</source>
        <translation>Секторлар өҫтөнә/с</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads merged/s</source>
        <translation>Хәтәләр бәйләнгән/с</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors written</source>
        <translation>Секторлар яҙылған</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Writes completed </source>
        <translation>Яҙылыш һәм ҡапланған </translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Writes merged</source>
        <translation>Яҙылыш бәйләнгән</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes/s</source>
        <translation>Яҙылыш/с</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Sectors written/s</source>
        <translation>Секторлар яҙылған/с</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes merged/s</source>
        <translation>Яҙылыш бәйләнгән/с</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="68"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="28"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="34"/>
        <source>Display shortcuts</source>
        <translation>Ҡысҡа ҡағиҙәләрҙе күрһәтеү</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="166"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Был процессын тамамлау һыҙыҡта үткән һыҙыҡта ҡапланышын һәм ҡапланышын үткән һыҙыҡта ҡапланышын ҡаплай алмай. Ҡына ҡаплай алмай, ҡаплайыгыҙ вә ҡаплайыгыҙ?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="510"/>
        <source>End process</source>
        <translation>Процесс тамамлау</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="367"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Процессын ҡына тамамлау ҡапланышын ҡаплай алмай. Ҡына тамамлауын ҡаплайыгыҙ вә ҡаплайыгыҙ?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="511"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Был ҡына ҡаплай алмай. Ҡына тамамлауын ҡаплайыгыҙ вә ҡаплайыгыҙ?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="519"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="520"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation type="unfinished">Force End</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>End</source>
        <comment>button</comment>
        <translation type="unfinished">End</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="299"/>
        <source>Logout</source>
        <translation>Тышҡын</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="172"/>
        <source>Settings</source>
        <translation>Төҙәтеү</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="47"/>
        <source>Size</source>
        <translation>Буйынсыҙлыҡ</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>IP address:</source>
        <translation>IP адресы:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Сетка маска:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Радио:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Префикс һаны:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Дөйөмләштереү:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Ҡына ҡапланышын ҡаплай алмай</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Сығанаҡ ҡапланышын ҡаплай алмай</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Сигнал ҡапланышын ҡаплай алмай</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Ҡапланышын ҡаплай алмай</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Буйынсыҙлыҡ</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>RX بакет</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>RX بايت</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>RX خطا</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>RX تم إسقاطه</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>RX تجاوز</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>RX إطار</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>TX بакет</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>TX بايت</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>TX خطا</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>TX تجاوز</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>TX حامل</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <source>IPv4</source>
        <translation>IPV4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <source>IPv6</source>
        <translation>IPV6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>TX تم إسقاطه</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="140"/>
        <source>Command line</source>
        <translation>خط الأوامر</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="145"/>
        <source>Start time</source>
        <translation>وقت البدء</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="135"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="146"/>
        <source>Click the application you want to end</source>
        <translation>اضغط على التطبيق الذي تريد إنهاؤه</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="144"/>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="89"/>
        <source>Receive</source>
        <translation>الاستقبال</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="220"/>
        <source>CPU</source>
        <translation>المعالج</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="145"/>
        <source>Disk read</source>
        <translation>القراءة من القرص</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="146"/>
        <source>Disk write</source>
        <translation>الكتابة على القرص</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="176"/>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="187"/>
        <source>Swap</source>
        <translation>التبديل</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="188"/>
        <source>Not enabled</source>
        <translation>غير مفعل</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="152"/>
        <source>Download</source>
        <translation>التنزيل</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="157"/>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="145"/>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="154"/>
        <source>Total Received</source>
        <translation>الإجمالي المستلم</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="159"/>
        <source>Total Sent</source>
        <translation>کۆپتى چاپ</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="98"/>
        <source>Send</source>
        <translation>چاپ</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="17"/>
        <source>Disks</source>
        <translation>دисكى</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>بارکۆکۈ</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="615"/>
        <source>Very high</source>
        <translation>تەكىسى چوڭ</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="623"/>
        <source>High</source>
        <translation>چوڭ</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="631"/>
        <source>Normal</source>
        <translation>ئادەتتەن</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="639"/>
        <source>Low</source>
        <translation>كەچكەن</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="647"/>
        <source>Very low</source>
        <translation>تەكىسى كەچكەن</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="655"/>
        <source>Custom</source>
        <translation>خەتىيە</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="60"/>
        <source>Invalid</source>
        <translation>نەچتەن</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="179"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, خاتې: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="138"/>
        <source>Failed to change process priority</source>
        <translation>پىرۇلىتىنى ئۆزگەرتىشنى بىلەلمەيدى</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>تەكىسى چوڭ</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>تېغىن چىقىشلىرىم</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>بەرى چىقىشلىرى</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="246"/>
        <source>Failed to pause process</source>
        <translation>پىرۇلىتىنى تۆگەرەك قىلىشنى بىلەلمەيدى</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="249"/>
        <source>Failed to resume process</source>
        <translation>پىرۇلىتىنى ئەرەقى قىلىشنى بىلەلمەيدى</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="252"/>
        <source>Failed to kill process</source>
        <translation>پىرۇلىتىنى تۆگەرەك قىلىشنى بىلەلمەيدى</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="255"/>
        <source>Unknown error</source>
        <translation>نىقىسى ھەتى</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="311"/>
        <source>Failed in sending signal to process</source>
        <translation>پىرۇلىتى ئۈچۈن سىگنال يۈкلىنىشتىن ھەتى بار</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="243"/>
        <source>Failed to end process</source>
        <translation>پىرۇلىتىنى بىتىرىشنى بىلەلمەيدى</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 تەكىسى چوڭ ۋە %2 پىرۇلىتى ئىشلەيدى)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="240"/>
        <source>No response</source>
        <translation>ھەتى بار</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="245"/>
        <source>Suspend</source>
        <translation>تۆگەرەك قىلىش</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="82"/>
        <source>Tray</source>
        <translation>تەكىسى چوڭ</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="662"/>
        <source>View command location</source>
        <translation>ئەملىيەت نۇقىتىنى كۆرۈش</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="79"/>
        <source>Properties</source>
        <translation>سۈرۆتلىرى</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="62"/>
        <source>End process</source>
        <translation>پىرۇلىتىنى بىتىرىش</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="74"/>
        <source>Resume process</source>
        <translation>پىرۇلىتىنى ئەرەقى قىلىش</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="85"/>
        <source>Kill process</source>
        <translation>Процес тык</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="609"/>
        <source>Change priority</source>
        <translation>Приоритет әләт</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="68"/>
        <source>Suspend process</source>
        <translation>Процес тормоз</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1024"/>
        <source>Custom Priority</source>
        <translation>Яңы Приоритет</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1056"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1058"/>
        <source>Change</source>
        <comment>button</comment>
        <translation type="unfinished">Change</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Исем</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Хәрәкәт</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Диск яз</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Диск оку</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Төгел</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Алгы</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Кеше</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Бүләнгән Хәрәкәт</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Виртуаль Хәрәкәт</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="366"/>
        <source>Not support</source>
        <translation>Тык әләт</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>Төзәтмәләр</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Систем һаҡлану</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Хәрәкәт үзгәреше үзгәреше һыҙыҡтан үткән була һаҡлау</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>CPU һаҡлану һыҙығы (%) </translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Хәрәкәт һаҡлану һыҙығы (%) </translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Һаҡлану аралығы (мин)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Хәбәрләр</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="322"/>
        <source>Failed to set service startup type</source>
        <translation>Хәрәкәт һыҙығы әҙерләү үткән</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="388"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Хәтта: Хәрәкәт һыҙығы әҙерләү үткән, ҡыҫҡы өйрәнеш буйынса үткән</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="150"/>
        <source>Service instance name</source>
        <translation>Хәрәкәт өйрәнеше исеме</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="34"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="35"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="114"/>
        <source>Refresh</source>
        <translation>Яңыртыу</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Start</source>
        <translation>Башлап</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="104"/>
        <source>Stop</source>
        <translation>Тәкъдим</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="109"/>
        <source>Restart</source>
        <translation>Тәкъдим һәм әртә</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="537"/>
        <source>Auto</source>
        <translation>Авт</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="538"/>
        <source>Manual</source>
        <translation>Мануал</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="536"/>
        <source>Startup type</source>
        <translation>Башланғыч төр</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Аты</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>Як</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Суб</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Тасвир</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Башланғыч төр</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Башланғыч хәл</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Башланғыч стратегия</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="124"/>
        <source>Settings</source>
        <translation>Тинтәш</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="156"/>
        <source>(Modifiable)</source>
        <translation>(Тәкъдим)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="263"/>
        <source>Range: %1-%2</source>
        <translation>Ия: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="55"/>
        <source>Force end application</source>
        <translation>Тәкъдим һәм әртә</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="140"/>
        <source>Expand</source>
        <translation>Күчерә</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="143"/>
        <source>Compact</source>
        <translation>Кысҡа</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="135"/>
        <source>View</source>
        <translation>Күрһәтә</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="40"/>
        <source>Search</source>
        <translation>Ҡаҙау</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="49"/>
        <source>Processes</source>
        <translation>Процессы</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="94"/>
        <source>Services</source>
        <translation>Сервис</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="234"/>
        <source>Users</source>
        <translation>Төп ҡатнашыусылар</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="97"/>
        <source>Edit account information</source>
        <translation>Аккаунт мәғлүмәтләрен түзә</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Administrator</source>
        <translation>Админ</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Standard User</source>
        <translation>Стандарт ҡатнашыусы</translation>
    </message>
</context>
</TS>
